Boost logo

Boost-Commit :

Subject: [Boost-commit] svn:boost r71795 - in trunk/libs/geometry: doc doc/doxy doc/src/examples doc/src/examples/ranges doc/src/examples/views test test/iterators test/ranges test/views
From: barend.gehrels_at_[hidden]
Date: 2011-05-07 18:13:20


Author: barendgehrels
Date: 2011-05-07 18:13:16 EDT (Sat, 07 May 2011)
New Revision: 71795
URL: http://svn.boost.org/trac/boost/changeset/71795

Log:
Test/docs (reflecting box_range->box_view and segment_range->segment_view)
Added:
   trunk/libs/geometry/doc/src/examples/views/
   trunk/libs/geometry/doc/src/examples/views/Jamfile.v2
      - copied, changed from r71715, /trunk/libs/geometry/doc/src/examples/ranges/Jamfile.v2
   trunk/libs/geometry/doc/src/examples/views/box_view.cpp
      - copied, changed from r71715, /trunk/libs/geometry/doc/src/examples/ranges/box_range.cpp
   trunk/libs/geometry/doc/src/examples/views/segment_view.cpp (contents, props changed)
   trunk/libs/geometry/test/views/box_view.cpp
      - copied, changed from r71629, /trunk/libs/geometry/test/ranges/box_range.cpp
   trunk/libs/geometry/test/views/box_view.vcproj
      - copied, changed from r71623, /trunk/libs/geometry/test/ranges/box_range.vcproj
   trunk/libs/geometry/test/views/segment_view.cpp
      - copied, changed from r71629, /trunk/libs/geometry/test/ranges/segment_range.cpp
   trunk/libs/geometry/test/views/segment_view.vcproj
      - copied, changed from r71623, /trunk/libs/geometry/test/ranges/segment_range.vcproj
Removed:
   trunk/libs/geometry/doc/src/examples/ranges/Jamfile.v2
   trunk/libs/geometry/doc/src/examples/ranges/box_range.cpp
   trunk/libs/geometry/test/iterators/box_iterator.cpp
   trunk/libs/geometry/test/iterators/box_iterator.vcproj
   trunk/libs/geometry/test/iterators/segment_range_iterator.cpp
   trunk/libs/geometry/test/iterators/segment_range_iterator.vcproj
   trunk/libs/geometry/test/ranges/box_range.cpp
   trunk/libs/geometry/test/ranges/box_range.vcproj
   trunk/libs/geometry/test/ranges/segment_range.cpp
   trunk/libs/geometry/test/ranges/segment_range.vcproj
Text files modified:
   trunk/libs/geometry/doc/doxy/Doxyfile | 1 -
   trunk/libs/geometry/doc/make_qbk.py | 11 ++++-------
   trunk/libs/geometry/doc/quickref.xml | 14 ++++++--------
   trunk/libs/geometry/doc/reference.qbk | 8 +++-----
   trunk/libs/geometry/doc/src/examples/Jamfile.v2 | 1 +
   trunk/libs/geometry/doc/src/examples/views/Jamfile.v2 | 5 +++--
   trunk/libs/geometry/doc/src/examples/views/box_view.cpp | 16 ++++++++--------
   trunk/libs/geometry/test/Jamfile.v2 | 1 -
   trunk/libs/geometry/test/iterators/Jamfile.v2 | 2 --
   trunk/libs/geometry/test/iterators/iterators.sln | 18 ------------------
   trunk/libs/geometry/test/views/Jamfile.v2 | 2 ++
   trunk/libs/geometry/test/views/box_view.cpp | 13 +++++++------
   trunk/libs/geometry/test/views/box_view.vcproj | 10 +++++-----
   trunk/libs/geometry/test/views/segment_view.cpp | 11 ++++++++---
   trunk/libs/geometry/test/views/segment_view.vcproj | 10 +++++-----
   trunk/libs/geometry/test/views/views.sln | 12 ++++++++++++
   16 files changed, 64 insertions(+), 71 deletions(-)

Modified: trunk/libs/geometry/doc/doxy/Doxyfile
==============================================================================
--- trunk/libs/geometry/doc/doxy/Doxyfile (original)
+++ trunk/libs/geometry/doc/doxy/Doxyfile 2011-05-07 18:13:16 EDT (Sat, 07 May 2011)
@@ -196,7 +196,6 @@
                         ../../../../boost/geometry/multi/strategies/cartesian \
                         ../../../../boost/geometry/policies \
                         ../../../../boost/geometry/policies/relate \
- ../../../../boost/geometry/ranges \
                         ../../../../boost/geometry/strategies \
                         ../../../../boost/geometry/strategies/concepts \
                         ../../../../boost/geometry/strategies/agnostic \

Modified: trunk/libs/geometry/doc/make_qbk.py
==============================================================================
--- trunk/libs/geometry/doc/make_qbk.py (original)
+++ trunk/libs/geometry/doc/make_qbk.py 2011-05-07 18:13:16 EDT (Sat, 07 May 2011)
@@ -88,14 +88,13 @@
 
 exceptions = ["exception", "centroid_exception"];
 
-iterators = ["box_iterator", "circular_iterator", "closing_iterator"
- , "ever_circling_iterator", "segment_range_iterator"]
+iterators = ["circular_iterator", "closing_iterator"
+ , "ever_circling_iterator"]
 
 models = ["point", "linestring", "box"
     , "polygon", "segment", "ring"
     , "multi_linestring", "multi_point", "multi_polygon", "referring_segment"]
 
-ranges = ["box_range", "segment_range"];
 
 strategies = ["distance::pythagoras", "distance::haversine"
     , "distance::cross_track", "distance::projected_point"
@@ -110,7 +109,8 @@
     , "transform::translate_transformer", "transform::ublas_transformer"
     ]
     
-views = ["closeable_view", "reversible_view", "identity_view"]
+views = ["box_view", "segment_view"
+ , "closeable_view", "reversible_view", "identity_view"]
 
 
 
@@ -135,9 +135,6 @@
 for i in models:
     model_to_quickbook(i)
    
-for i in ranges:
- class_to_quickbook(i)
-
 for i in strategies:
     strategy_to_quickbook(i)
 

Modified: trunk/libs/geometry/doc/quickref.xml
==============================================================================
--- trunk/libs/geometry/doc/quickref.xml (original)
+++ trunk/libs/geometry/doc/quickref.xml 2011-05-07 18:13:16 EDT (Sat, 07 May 2011)
@@ -270,7 +270,7 @@
     <bridgehead renderas="sect2">Iterators</bridgehead>
    </entry>
    <entry valign="center" namest="b" nameend="b">
- <bridgehead renderas="sect2">Ranges</bridgehead>
+ <bridgehead renderas="sect2">Views</bridgehead>
    </entry>
   </row>
  </thead>
@@ -281,17 +281,15 @@
     <member><link linkend="geometry.reference.iterators.closing_iterator">closing_iterator</link></member>
     <member><link linkend="geometry.reference.iterators.circular_iterator">circular_iterator</link></member>
     <member><link linkend="geometry.reference.iterators.ever_circling_iterator">ever_circling_iterator</link></member>
- <member><link linkend="geometry.reference.iterators.box_iterator">box_iterator</link></member>
- <member><link linkend="geometry.reference.iterators.segment_range_iterator">segment_range_iterator</link></member>
     </simplelist>
    </entry>
    <entry valign="top">
     <simplelist type="vert" columns="1">
- <member><link linkend="geometry.reference.ranges.box_range">box_range</link></member>
- <member><link linkend="geometry.reference.ranges.segment_range">segment_range</link></member>
- <member><link linkend="geometry.reference.ranges.closeable_view">closeable_view</link></member>
- <member><link linkend="geometry.reference.ranges.reversible_view">reversible_view</link></member>
- <member><link linkend="geometry.reference.ranges.identity_view">identity_view</link></member>
+ <member><link linkend="geometry.reference.views.box_view">box_view</link></member>
+ <member><link linkend="geometry.reference.views.segment_view">segment_view</link></member>
+ <member><link linkend="geometry.reference.views.closeable_view">closeable_view</link></member>
+ <member><link linkend="geometry.reference.views.reversible_view">reversible_view</link></member>
+ <member><link linkend="geometry.reference.views.identity_view">identity_view</link></member>
     </simplelist>
    </entry>
   </row>

Modified: trunk/libs/geometry/doc/reference.qbk
==============================================================================
--- trunk/libs/geometry/doc/reference.qbk (original)
+++ trunk/libs/geometry/doc/reference.qbk 2011-05-07 18:13:16 EDT (Sat, 07 May 2011)
@@ -211,10 +211,8 @@
 
 [section:iterators Iterators]
 [include generated/closing_iterator.qbk]
-[include generated/box_iterator.qbk]
 [include generated/circular_iterator.qbk]
 [include generated/ever_circling_iterator.qbk]
-[include generated/segment_range_iterator.qbk]
 [endsect]
 
 
@@ -259,9 +257,9 @@
 [endsect]
 
 
-[section:ranges Ranges]
-[include generated/box_range.qbk]
-[include generated/segment_range.qbk]
+[section:views Views]
+[include generated/box_view.qbk]
+[include generated/segment_view.qbk]
 [include generated/closeable_view.qbk]
 [include generated/reversible_view.qbk]
 [include generated/identity_view.qbk]

Modified: trunk/libs/geometry/doc/src/examples/Jamfile.v2
==============================================================================
--- trunk/libs/geometry/doc/src/examples/Jamfile.v2 (original)
+++ trunk/libs/geometry/doc/src/examples/Jamfile.v2 2011-05-07 18:13:16 EDT (Sat, 07 May 2011)
@@ -18,3 +18,4 @@
 build-project algorithms ;
 build-project core ;
 build-project geometries ;
+build-project views ;

Deleted: trunk/libs/geometry/doc/src/examples/ranges/Jamfile.v2
==============================================================================
--- trunk/libs/geometry/doc/src/examples/ranges/Jamfile.v2 2011-05-07 18:13:16 EDT (Sat, 07 May 2011)
+++ (empty file)
@@ -1,16 +0,0 @@
-# Boost.Geometry (aka GGL, Generic Geometry Library)
-#
-# Copyright (c) 2007-2011 Barend Gehrels, Amsterdam, the Netherlands.
-# Copyright (c) 2008-2011 Bruno Lalande, Paris, France.
-# Copyright (c) 2009-2011 Mateusz Loskot, London, UK.
-
-# Use, modification and distribution is subject to the Boost Software License,
-# Version 1.0. (See accompanying file LICENSE_1_0.txt or copy at
-# http://www.boost.org/LICENSE_1_0.txt)
-
-
-project boost-geometry-doc-example-ranges
- : # requirements
- ;
-
-exe box_range : box_range.cpp ;

Deleted: trunk/libs/geometry/doc/src/examples/ranges/box_range.cpp
==============================================================================
--- trunk/libs/geometry/doc/src/examples/ranges/box_range.cpp 2011-05-07 18:13:16 EDT (Sat, 07 May 2011)
+++ (empty file)
@@ -1,58 +0,0 @@
-// Boost.Geometry (aka GGL, Generic Geometry Library)
-// QuickBook Example
-
-// Copyright (c) 2011 Barend Gehrels, Amsterdam, the Netherlands.
-
-// Use, modification and distribution is subject to the Boost Software License,
-// Version 1.0. (See accompanying file LICENSE_1_0.txt or copy at
-// http://www.boost.org/LICENSE_1_0.txt)
-
-//[box_range
-//` Shows usage of the Boost.Range compatible view on a box
-
-#include <iostream>
-
-#include <boost/geometry.hpp>
-
-
-int main()
-{
- typedef boost::geometry::model::box
- <
- boost::geometry::model::point<double, 2, boost::geometry::cs::cartesian>
- > box_type;
-
- // Define the Boost.Range compatible type:
- typedef boost::geometry::box_range<box_type> box_range;
-
- box_type box;
- boost::geometry::assign_values(box, 0, 0, 4, 4);
-
- box_range range(box);
-
- // Iterating in clockwise direction over the points of this box
- for (boost::range_iterator<box_range const>::type it = boost::begin(range);
- it != boost::end(range); ++it)
- {
- std::cout << " " << boost::geometry::dsv(*it);
- }
- std::cout << std::endl;
-
- // Note that a box_range is tagged as a ring, so supports area etc.
- std::cout << "Area: " << boost::geometry::area(range) << std::endl;
-
- return 0;
-}
-
-//]
-
-
-//[box_range_output
-/*`
-Output:
-[pre
- (0, 0) (0, 4) (4, 4) (4, 0) (0, 0)
-Area: 16
-]
-*/
-//]

Copied: trunk/libs/geometry/doc/src/examples/views/Jamfile.v2 (from r71715, /trunk/libs/geometry/doc/src/examples/ranges/Jamfile.v2)
==============================================================================
--- /trunk/libs/geometry/doc/src/examples/ranges/Jamfile.v2 (original)
+++ trunk/libs/geometry/doc/src/examples/views/Jamfile.v2 2011-05-07 18:13:16 EDT (Sat, 07 May 2011)
@@ -9,8 +9,9 @@
 # http://www.boost.org/LICENSE_1_0.txt)
 
 
-project boost-geometry-doc-example-ranges
+project boost-geometry-doc-example-views
     : # requirements
     ;
 
-exe box_range : box_range.cpp ;
+exe box_view : box_view.cpp ;
+exe segment_view : segment_view.cpp ;

Copied: trunk/libs/geometry/doc/src/examples/views/box_view.cpp (from r71715, /trunk/libs/geometry/doc/src/examples/ranges/box_range.cpp)
==============================================================================
--- (empty file)
+++ trunk/libs/geometry/doc/src/examples/views/segment_view.cpp 2011-05-07 18:13:16 EDT (Sat, 07 May 2011)
@@ -0,0 +1,57 @@
+// Boost.Geometry (aka GGL, Generic Geometry Library)
+// QuickBook Example
+
+// Copyright (c) 2011 Barend Gehrels, Amsterdam, the Netherlands.
+
+// Use, modification and distribution is subject to the Boost Software License,
+// Version 1.0. (See accompanying file LICENSE_1_0.txt or copy at
+// http://www.boost.org/LICENSE_1_0.txt)
+
+//[segment_view
+//` Shows usage of the Boost.Range compatible view on a box
+
+#include <iostream>
+
+#include <boost/geometry.hpp>
+
+
+int main()
+{
+ typedef boost::geometry::model::segment
+ <
+ boost::geometry::model::point<double, 2, boost::geometry::cs::cartesian>
+ > segment_type;
+
+ typedef boost::geometry::segment_view<segment_type> segment_view;
+
+ segment_type segment;
+ boost::geometry::assign_values(segment, 0, 0, 1, 1);
+
+ segment_view view(segment);
+
+ // Iterating over the points of this segment
+ for (boost::range_iterator<segment_view const>::type it = boost::begin(view);
+ it != boost::end(view); ++it)
+ {
+ std::cout << " " << boost::geometry::dsv(*it);
+ }
+ std::cout << std::endl;
+
+ // Note that a segment_view is tagged as a linestring, so supports length etc.
+ std::cout << "Length: " << boost::geometry::length(view) << std::endl;
+
+ return 0;
+}
+
+//]
+
+
+//[segment_view_output
+/*`
+Output:
+[pre
+ (0, 0) (0, 4) (4, 4) (4, 0) (0, 0)
+Area: 16
+]
+*/
+//]

Modified: trunk/libs/geometry/test/Jamfile.v2
==============================================================================
--- trunk/libs/geometry/test/Jamfile.v2 (original)
+++ trunk/libs/geometry/test/Jamfile.v2 2011-05-07 18:13:16 EDT (Sat, 07 May 2011)
@@ -25,7 +25,6 @@
 build-project arithmetic ;
 build-project algorithms ;
 build-project iterators ;
-build-project ranges ;
 build-project strategies ;
 build-project policies ;
 build-project util ;

Modified: trunk/libs/geometry/test/iterators/Jamfile.v2
==============================================================================
--- trunk/libs/geometry/test/iterators/Jamfile.v2 (original)
+++ trunk/libs/geometry/test/iterators/Jamfile.v2 2011-05-07 18:13:16 EDT (Sat, 07 May 2011)
@@ -10,9 +10,7 @@
 
 test-suite boost-geometry-iterators
     :
- [ run box_iterator.cpp ]
     [ run circular_iterator.cpp ]
     [ run closing_iterator.cpp ]
     [ run ever_circling_iterator.cpp ]
- [ run segment_range_iterator.cpp ]
     ;

Deleted: trunk/libs/geometry/test/iterators/box_iterator.cpp
==============================================================================
--- trunk/libs/geometry/test/iterators/box_iterator.cpp 2011-05-07 18:13:16 EDT (Sat, 07 May 2011)
+++ (empty file)
@@ -1,54 +0,0 @@
-// Boost.Geometry (aka GGL, Generic Box Library)
-//
-// Copyright (c) 2010 Barend Gehrels, Amsterdam, the Netherlands.
-// Use, modification and distribution is subject to the Boost Software License,
-// Version 1.0. (See accompanying file LICENSE_1_0.txt or copy at
-// http://www.boost.org/LICENSE_1_0.txt)
-
-#include <algorithm>
-#include <sstream>
-#include <string>
-#include <vector>
-
-#include <geometry_test_common.hpp>
-
-#include <boost/geometry/core/coordinate_type.hpp>
-#include <boost/geometry/geometries/geometries.hpp>
-#include <boost/geometry/iterators/box_iterator.hpp>
-#include <boost/geometry/domains/gis/io/wkt/read_wkt.hpp>
-
-#include <test_geometries/custom_segment.hpp>
-
-
-template <typename Box>
-void test_geometry(std::string const& wkt, std::string const& expected)
-{
- Box box;
- bg::read_wkt(wkt, box);
-
- {
- std::ostringstream out;
- bg::box_iterator<Box> it(box), end(box, true);
- for ( ; it != end; ++it)
- {
- out << " " << bg::get<0>(*it) << bg::get<1>(*it);
- }
- BOOST_CHECK_EQUAL(out.str(), expected);
- }
-}
-
-
-template <typename P>
-void test_all()
-{
- test_geometry<bg::model::box<P> >("polygon((1 1,2 2))", " 11 12 22 21 11");
- test_geometry<bg::model::box<P> >("polygon((3 3,5 5))", " 33 35 55 53 33");
-}
-
-
-int test_main(int, char* [])
-{
- test_all<bg::model::d2::point_xy<double> >();
-
- return 0;
-}

Deleted: trunk/libs/geometry/test/iterators/box_iterator.vcproj
==============================================================================
--- trunk/libs/geometry/test/iterators/box_iterator.vcproj 2011-05-07 18:13:16 EDT (Sat, 07 May 2011)
+++ (empty file)
@@ -1,176 +0,0 @@
-<?xml version="1.0" encoding="Windows-1252"?>
-<VisualStudioProject
- ProjectType="Visual C++"
- Version="8.00"
- Name="box_iterator"
- ProjectGUID="{CD4B14B2-ED74-4111-B8BF-093FA3930A5C}"
- RootNamespace="box_iterator"
- Keyword="Win32Proj"
- >
- <Platforms>
- <Platform
- Name="Win32"
- />
- </Platforms>
- <ToolFiles>
- </ToolFiles>
- <Configurations>
- <Configuration
- Name="Debug|Win32"
- OutputDirectory="$(SolutionDir)$(ConfigurationName)"
- IntermediateDirectory="$(ConfigurationName)\box_iterator"
- ConfigurationType="1"
- InheritedPropertySheets="..\boost.vsprops"
- CharacterSet="1"
- >
- <Tool
- Name="VCPreBuildEventTool"
- />
- <Tool
- Name="VCCustomBuildTool"
- />
- <Tool
- Name="VCXMLDataGeneratorTool"
- />
- <Tool
- Name="VCWebServiceProxyGeneratorTool"
- />
- <Tool
- Name="VCMIDLTool"
- />
- <Tool
- Name="VCCLCompilerTool"
- Optimization="0"
- AdditionalIncludeDirectories="../../../..;.."
- PreprocessorDefinitions="WIN32;_DEBUG;_CONSOLE"
- ExceptionHandling="2"
- RuntimeLibrary="1"
- UsePrecompiledHeader="0"
- DebugInformationFormat="1"
- />
- <Tool
- Name="VCManagedResourceCompilerTool"
- />
- <Tool
- Name="VCResourceCompilerTool"
- />
- <Tool
- Name="VCPreLinkEventTool"
- />
- <Tool
- Name="VCLinkerTool"
- GenerateDebugInformation="true"
- SubSystem="1"
- TargetMachine="1"
- />
- <Tool
- Name="VCALinkTool"
- />
- <Tool
- Name="VCManifestTool"
- EmbedManifest="false"
- />
- <Tool
- Name="VCXDCMakeTool"
- />
- <Tool
- Name="VCBscMakeTool"
- />
- <Tool
- Name="VCFxCopTool"
- />
- <Tool
- Name="VCAppVerifierTool"
- />
- <Tool
- Name="VCWebDeploymentTool"
- />
- <Tool
- Name="VCPostBuildEventTool"
- />
- </Configuration>
- <Configuration
- Name="Release|Win32"
- OutputDirectory="$(SolutionDir)$(ConfigurationName)"
- IntermediateDirectory="$(ConfigurationName)\box_iterator"
- ConfigurationType="1"
- InheritedPropertySheets="..\boost.vsprops"
- CharacterSet="1"
- WholeProgramOptimization="1"
- >
- <Tool
- Name="VCPreBuildEventTool"
- />
- <Tool
- Name="VCCustomBuildTool"
- />
- <Tool
- Name="VCXMLDataGeneratorTool"
- />
- <Tool
- Name="VCWebServiceProxyGeneratorTool"
- />
- <Tool
- Name="VCMIDLTool"
- />
- <Tool
- Name="VCCLCompilerTool"
- AdditionalIncludeDirectories="../../../..;.."
- PreprocessorDefinitions="WIN32;NDEBUG;_CONSOLE"
- ExceptionHandling="2"
- UsePrecompiledHeader="0"
- />
- <Tool
- Name="VCManagedResourceCompilerTool"
- />
- <Tool
- Name="VCResourceCompilerTool"
- />
- <Tool
- Name="VCPreLinkEventTool"
- />
- <Tool
- Name="VCLinkerTool"
- SubSystem="1"
- OptimizeReferences="2"
- EnableCOMDATFolding="2"
- TargetMachine="1"
- />
- <Tool
- Name="VCALinkTool"
- />
- <Tool
- Name="VCManifestTool"
- EmbedManifest="false"
- />
- <Tool
- Name="VCXDCMakeTool"
- />
- <Tool
- Name="VCBscMakeTool"
- />
- <Tool
- Name="VCFxCopTool"
- />
- <Tool
- Name="VCAppVerifierTool"
- />
- <Tool
- Name="VCWebDeploymentTool"
- />
- <Tool
- Name="VCPostBuildEventTool"
- />
- </Configuration>
- </Configurations>
- <References>
- </References>
- <Files>
- <File
- RelativePath=".\box_iterator.cpp"
- >
- </File>
- </Files>
- <Globals>
- </Globals>
-</VisualStudioProject>

Modified: trunk/libs/geometry/test/iterators/iterators.sln
==============================================================================
--- trunk/libs/geometry/test/iterators/iterators.sln (original)
+++ trunk/libs/geometry/test/iterators/iterators.sln 2011-05-07 18:13:16 EDT (Sat, 07 May 2011)
@@ -6,12 +6,6 @@
 EndProject
 Project("{8BC9CEB8-8B4A-11D0-8D11-00A0C91BC942}") = "closing_iterator", "closing_iterator.vcproj", "{04C31A2D-BE88-4FDB-AFFE-EFDFFA9D9C39}"
 EndProject
-Project("{8BC9CEB8-8B4A-11D0-8D11-00A0C91BC942}") = "segment_range_iterator", "segment_range_iterator.vcproj", "{887E64C9-6786-44E2-AE09-B02B855486DE}"
-EndProject
-Project("{8BC9CEB8-8B4A-11D0-8D11-00A0C91BC942}") = "box_iterator", "box_iterator.vcproj", "{CD4B14B2-ED74-4111-B8BF-093FA3930A5C}"
-EndProject
-Project("{8BC9CEB8-8B4A-11D0-8D11-00A0C91BC942}") = "segment_returning_iterator", "segment_returning_iterator.vcproj", "{A38B1CA8-5194-4FAD-B85E-55697BEECCB7}"
-EndProject
 Global
         GlobalSection(SolutionConfigurationPlatforms) = preSolution
                 Debug|Win32 = Debug|Win32
@@ -30,18 +24,6 @@
                 {04C31A2D-BE88-4FDB-AFFE-EFDFFA9D9C39}.Debug|Win32.Build.0 = Debug|Win32
                 {04C31A2D-BE88-4FDB-AFFE-EFDFFA9D9C39}.Release|Win32.ActiveCfg = Release|Win32
                 {04C31A2D-BE88-4FDB-AFFE-EFDFFA9D9C39}.Release|Win32.Build.0 = Release|Win32
- {887E64C9-6786-44E2-AE09-B02B855486DE}.Debug|Win32.ActiveCfg = Debug|Win32
- {887E64C9-6786-44E2-AE09-B02B855486DE}.Debug|Win32.Build.0 = Debug|Win32
- {887E64C9-6786-44E2-AE09-B02B855486DE}.Release|Win32.ActiveCfg = Release|Win32
- {887E64C9-6786-44E2-AE09-B02B855486DE}.Release|Win32.Build.0 = Release|Win32
- {CD4B14B2-ED74-4111-B8BF-093FA3930A5C}.Debug|Win32.ActiveCfg = Debug|Win32
- {CD4B14B2-ED74-4111-B8BF-093FA3930A5C}.Debug|Win32.Build.0 = Debug|Win32
- {CD4B14B2-ED74-4111-B8BF-093FA3930A5C}.Release|Win32.ActiveCfg = Release|Win32
- {CD4B14B2-ED74-4111-B8BF-093FA3930A5C}.Release|Win32.Build.0 = Release|Win32
- {A38B1CA8-5194-4FAD-B85E-55697BEECCB7}.Debug|Win32.ActiveCfg = Debug|Win32
- {A38B1CA8-5194-4FAD-B85E-55697BEECCB7}.Debug|Win32.Build.0 = Debug|Win32
- {A38B1CA8-5194-4FAD-B85E-55697BEECCB7}.Release|Win32.ActiveCfg = Release|Win32
- {A38B1CA8-5194-4FAD-B85E-55697BEECCB7}.Release|Win32.Build.0 = Release|Win32
         EndGlobalSection
         GlobalSection(SolutionProperties) = preSolution
                 HideSolutionNode = FALSE

Deleted: trunk/libs/geometry/test/iterators/segment_range_iterator.cpp
==============================================================================
--- trunk/libs/geometry/test/iterators/segment_range_iterator.cpp 2011-05-07 18:13:16 EDT (Sat, 07 May 2011)
+++ (empty file)
@@ -1,52 +0,0 @@
-// Boost.Geometry (aka GGL, Generic Segment Library)
-//
-// Copyright (c) 2010 Barend Gehrels, Amsterdam, the Netherlands.
-// Use, modification and distribution is subject to the Boost Software License,
-// Version 1.0. (See accompanying file LICENSE_1_0.txt or copy at
-// http://www.boost.org/LICENSE_1_0.txt)
-
-#include <algorithm>
-#include <sstream>
-#include <string>
-#include <vector>
-
-#include <geometry_test_common.hpp>
-
-#include <boost/geometry/core/coordinate_type.hpp>
-#include <boost/geometry/geometries/geometries.hpp>
-#include <boost/geometry/iterators/segment_range_iterator.hpp>
-#include <boost/geometry/domains/gis/io/wkt/read_wkt.hpp>
-
-#include <test_geometries/custom_segment.hpp>
-
-
-template <typename Segment>
-void test_geometry(std::string const& wkt, std::string const& expected)
-{
- Segment segment;
- bg::read_wkt(wkt, segment);
-
- std::ostringstream out;
- bg::segment_range_iterator<Segment> it(segment), end(segment, true);
- for ( ; it != end; ++it)
- {
- out << " " << bg::get<0>(*it) << bg::get<1>(*it);
- }
- BOOST_CHECK_EQUAL(out.str(), expected);
-}
-
-
-template <typename P>
-void test_all()
-{
- test_geometry<test::custom_segment>("linestring(1 1,2 2)", " 11 22");
- test_geometry<test::custom_segment>("linestring(4 4,3 3)", " 44 33");
-}
-
-
-int test_main(int, char* [])
-{
- test_all<bg::model::d2::point_xy<double> >();
-
- return 0;
-}

Deleted: trunk/libs/geometry/test/iterators/segment_range_iterator.vcproj
==============================================================================
--- trunk/libs/geometry/test/iterators/segment_range_iterator.vcproj 2011-05-07 18:13:16 EDT (Sat, 07 May 2011)
+++ (empty file)
@@ -1,176 +0,0 @@
-<?xml version="1.0" encoding="Windows-1252"?>
-<VisualStudioProject
- ProjectType="Visual C++"
- Version="8.00"
- Name="segment_range_iterator"
- ProjectGUID="{887E64C9-6786-44E2-AE09-B02B855486DE}"
- RootNamespace="segment_range_iterator"
- Keyword="Win32Proj"
- >
- <Platforms>
- <Platform
- Name="Win32"
- />
- </Platforms>
- <ToolFiles>
- </ToolFiles>
- <Configurations>
- <Configuration
- Name="Debug|Win32"
- OutputDirectory="$(SolutionDir)$(ConfigurationName)"
- IntermediateDirectory="$(ConfigurationName)\segment_range_iterator"
- ConfigurationType="1"
- InheritedPropertySheets="..\boost.vsprops"
- CharacterSet="1"
- >
- <Tool
- Name="VCPreBuildEventTool"
- />
- <Tool
- Name="VCCustomBuildTool"
- />
- <Tool
- Name="VCXMLDataGeneratorTool"
- />
- <Tool
- Name="VCWebServiceProxyGeneratorTool"
- />
- <Tool
- Name="VCMIDLTool"
- />
- <Tool
- Name="VCCLCompilerTool"
- Optimization="0"
- AdditionalIncludeDirectories="../../../..;.."
- PreprocessorDefinitions="WIN32;_DEBUG;_CONSOLE"
- ExceptionHandling="2"
- RuntimeLibrary="1"
- UsePrecompiledHeader="0"
- DebugInformationFormat="1"
- />
- <Tool
- Name="VCManagedResourceCompilerTool"
- />
- <Tool
- Name="VCResourceCompilerTool"
- />
- <Tool
- Name="VCPreLinkEventTool"
- />
- <Tool
- Name="VCLinkerTool"
- GenerateDebugInformation="true"
- SubSystem="1"
- TargetMachine="1"
- />
- <Tool
- Name="VCALinkTool"
- />
- <Tool
- Name="VCManifestTool"
- EmbedManifest="false"
- />
- <Tool
- Name="VCXDCMakeTool"
- />
- <Tool
- Name="VCBscMakeTool"
- />
- <Tool
- Name="VCFxCopTool"
- />
- <Tool
- Name="VCAppVerifierTool"
- />
- <Tool
- Name="VCWebDeploymentTool"
- />
- <Tool
- Name="VCPostBuildEventTool"
- />
- </Configuration>
- <Configuration
- Name="Release|Win32"
- OutputDirectory="$(SolutionDir)$(ConfigurationName)"
- IntermediateDirectory="$(ConfigurationName)\segment_range_iterator"
- ConfigurationType="1"
- InheritedPropertySheets="..\boost.vsprops"
- CharacterSet="1"
- WholeProgramOptimization="1"
- >
- <Tool
- Name="VCPreBuildEventTool"
- />
- <Tool
- Name="VCCustomBuildTool"
- />
- <Tool
- Name="VCXMLDataGeneratorTool"
- />
- <Tool
- Name="VCWebServiceProxyGeneratorTool"
- />
- <Tool
- Name="VCMIDLTool"
- />
- <Tool
- Name="VCCLCompilerTool"
- AdditionalIncludeDirectories="../../../..;.."
- PreprocessorDefinitions="WIN32;NDEBUG;_CONSOLE"
- ExceptionHandling="2"
- UsePrecompiledHeader="0"
- />
- <Tool
- Name="VCManagedResourceCompilerTool"
- />
- <Tool
- Name="VCResourceCompilerTool"
- />
- <Tool
- Name="VCPreLinkEventTool"
- />
- <Tool
- Name="VCLinkerTool"
- SubSystem="1"
- OptimizeReferences="2"
- EnableCOMDATFolding="2"
- TargetMachine="1"
- />
- <Tool
- Name="VCALinkTool"
- />
- <Tool
- Name="VCManifestTool"
- EmbedManifest="false"
- />
- <Tool
- Name="VCXDCMakeTool"
- />
- <Tool
- Name="VCBscMakeTool"
- />
- <Tool
- Name="VCFxCopTool"
- />
- <Tool
- Name="VCAppVerifierTool"
- />
- <Tool
- Name="VCWebDeploymentTool"
- />
- <Tool
- Name="VCPostBuildEventTool"
- />
- </Configuration>
- </Configurations>
- <References>
- </References>
- <Files>
- <File
- RelativePath=".\segment_range_iterator.cpp"
- >
- </File>
- </Files>
- <Globals>
- </Globals>
-</VisualStudioProject>

Deleted: trunk/libs/geometry/test/ranges/box_range.cpp
==============================================================================
--- trunk/libs/geometry/test/ranges/box_range.cpp 2011-05-07 18:13:16 EDT (Sat, 07 May 2011)
+++ (empty file)
@@ -1,75 +0,0 @@
-// Boost.Geometry (aka GGL, Generic Geometry Library)
-// Unit Test
-
-// Copyright (c) 2010 Barend Gehrels, Amsterdam, the Netherlands.
-
-// Use, modification and distribution is subject to the Boost Software License,
-// Version 1.0. (See accompanying file LICENSE_1_0.txt or copy at
-// http://www.boost.org/LICENSE_1_0.txt)
-
-#include <algorithm>
-#include <iterator>
-#include <sstream>
-#include <string>
-
-#include <geometry_test_common.hpp>
-
-#include <boost/geometry/geometries/geometries.hpp>
-#include <boost/geometry/geometries/point_xy.hpp>
-#include <boost/geometry/ranges/box_range.hpp>
-#include <boost/geometry/domains/gis/io/wkt/read_wkt.hpp>
-
-
-
-template <typename Box>
-void test_geometry(std::string const& wkt, std::string const& expected)
-{
-
- Box box;
- bg::read_wkt(wkt, box);
-
- typedef bg::box_range<Box> range_type;
- range_type range(box);
-
- {
- std::ostringstream out;
- for (typename boost::range_iterator<range_type>::type it = boost::begin(range);
- it != boost::end(range); ++it)
- {
- out << " " << bg::get<0>(*it) << bg::get<1>(*it);
- }
- BOOST_CHECK_EQUAL(out.str(), expected);
- }
-
- {
- // Check forward/backward behaviour
- typename boost::range_iterator<range_type>::type it = boost::begin(range);
- it++;
- it--;
- // Not verified further, same as segment
- }
-
- {
- // Check random access behaviour
- int const n = boost::size(range);
- BOOST_CHECK_EQUAL(n, 5);
- }
-
- // Check Boost.Range concept
- BOOST_CONCEPT_ASSERT( (boost::ForwardRangeConcept<range_type>) );
-}
-
-
-template <typename P>
-void test_all()
-{
- test_geometry<bg::model::box<P> >("polygon((1 1,2 2))", " 11 12 22 21 11");
- test_geometry<bg::model::box<P> >("polygon((3 3,5 5))", " 33 35 55 53 33");
-}
-
-
-int test_main(int, char* [])
-{
- test_all<bg::model::d2::point_xy<double> >();
- return 0;
-}

Deleted: trunk/libs/geometry/test/ranges/box_range.vcproj
==============================================================================
--- trunk/libs/geometry/test/ranges/box_range.vcproj 2011-05-07 18:13:16 EDT (Sat, 07 May 2011)
+++ (empty file)
@@ -1,178 +0,0 @@
-<?xml version="1.0" encoding="Windows-1252"?>
-<VisualStudioProject
- ProjectType="Visual C++"
- Version="8.00"
- Name="box_range"
- ProjectGUID="{34A1F53A-DA46-41E6-9E26-740D22D662DC}"
- RootNamespace="box_range"
- Keyword="Win32Proj"
- >
- <Platforms>
- <Platform
- Name="Win32"
- />
- </Platforms>
- <ToolFiles>
- </ToolFiles>
- <Configurations>
- <Configuration
- Name="Debug|Win32"
- OutputDirectory="$(SolutionDir)$(ConfigurationName)"
- IntermediateDirectory="$(ConfigurationName)\box_range"
- ConfigurationType="1"
- InheritedPropertySheets="..\boost.vsprops"
- CharacterSet="1"
- >
- <Tool
- Name="VCPreBuildEventTool"
- />
- <Tool
- Name="VCCustomBuildTool"
- />
- <Tool
- Name="VCXMLDataGeneratorTool"
- />
- <Tool
- Name="VCWebServiceProxyGeneratorTool"
- />
- <Tool
- Name="VCMIDLTool"
- />
- <Tool
- Name="VCCLCompilerTool"
- Optimization="0"
- AdditionalIncludeDirectories="../../../..;.."
- PreprocessorDefinitions="WIN32;_DEBUG;_CONSOLE"
- ExceptionHandling="2"
- RuntimeLibrary="1"
- UsePrecompiledHeader="0"
- WarningLevel="3"
- DebugInformationFormat="1"
- />
- <Tool
- Name="VCManagedResourceCompilerTool"
- />
- <Tool
- Name="VCResourceCompilerTool"
- />
- <Tool
- Name="VCPreLinkEventTool"
- />
- <Tool
- Name="VCLinkerTool"
- GenerateDebugInformation="true"
- SubSystem="1"
- TargetMachine="1"
- />
- <Tool
- Name="VCALinkTool"
- />
- <Tool
- Name="VCManifestTool"
- EmbedManifest="false"
- />
- <Tool
- Name="VCXDCMakeTool"
- />
- <Tool
- Name="VCBscMakeTool"
- />
- <Tool
- Name="VCFxCopTool"
- />
- <Tool
- Name="VCAppVerifierTool"
- />
- <Tool
- Name="VCWebDeploymentTool"
- />
- <Tool
- Name="VCPostBuildEventTool"
- />
- </Configuration>
- <Configuration
- Name="Release|Win32"
- OutputDirectory="$(SolutionDir)$(ConfigurationName)"
- IntermediateDirectory="$(ConfigurationName)\box_range"
- ConfigurationType="1"
- InheritedPropertySheets="..\boost.vsprops"
- CharacterSet="1"
- WholeProgramOptimization="1"
- >
- <Tool
- Name="VCPreBuildEventTool"
- />
- <Tool
- Name="VCCustomBuildTool"
- />
- <Tool
- Name="VCXMLDataGeneratorTool"
- />
- <Tool
- Name="VCWebServiceProxyGeneratorTool"
- />
- <Tool
- Name="VCMIDLTool"
- />
- <Tool
- Name="VCCLCompilerTool"
- AdditionalIncludeDirectories="../../../..;.."
- PreprocessorDefinitions="WIN32;NDEBUG;_CONSOLE"
- ExceptionHandling="2"
- UsePrecompiledHeader="0"
- WarningLevel="3"
- />
- <Tool
- Name="VCManagedResourceCompilerTool"
- />
- <Tool
- Name="VCResourceCompilerTool"
- />
- <Tool
- Name="VCPreLinkEventTool"
- />
- <Tool
- Name="VCLinkerTool"
- SubSystem="1"
- OptimizeReferences="2"
- EnableCOMDATFolding="2"
- TargetMachine="1"
- />
- <Tool
- Name="VCALinkTool"
- />
- <Tool
- Name="VCManifestTool"
- EmbedManifest="false"
- />
- <Tool
- Name="VCXDCMakeTool"
- />
- <Tool
- Name="VCBscMakeTool"
- />
- <Tool
- Name="VCFxCopTool"
- />
- <Tool
- Name="VCAppVerifierTool"
- />
- <Tool
- Name="VCWebDeploymentTool"
- />
- <Tool
- Name="VCPostBuildEventTool"
- />
- </Configuration>
- </Configurations>
- <References>
- </References>
- <Files>
- <File
- RelativePath=".\box_range.cpp"
- >
- </File>
- </Files>
- <Globals>
- </Globals>
-</VisualStudioProject>

Deleted: trunk/libs/geometry/test/ranges/segment_range.cpp
==============================================================================
--- trunk/libs/geometry/test/ranges/segment_range.cpp 2011-05-07 18:13:16 EDT (Sat, 07 May 2011)
+++ (empty file)
@@ -1,80 +0,0 @@
-// Boost.Geometry (aka GGL, Generic Geometry Library)
-// Unit Test
-
-// Copyright (c) 2010 Barend Gehrels, Amsterdam, the Netherlands.
-
-// Use, modification and distribution is subject to the Boost Software License,
-// Version 1.0. (See accompanying file LICENSE_1_0.txt or copy at
-// http://www.boost.org/LICENSE_1_0.txt)
-
-#include <algorithm>
-#include <iterator>
-#include <sstream>
-#include <string>
-
-#include <geometry_test_common.hpp>
-
-#include <boost/geometry/geometries/geometries.hpp>
-#include <boost/geometry/ranges/segment_range.hpp>
-#include <boost/geometry/domains/gis/io/wkt/read_wkt.hpp>
-
-
-
-template <typename Segment>
-void test_geometry(std::string const& wkt, std::string const& expected)
-{
-
- Segment segment;
- bg::read_wkt(wkt, segment);
-
- typedef bg::segment_range<Segment> range_type;
- range_type range(segment);
-
- {
- std::ostringstream out;
- for (typename boost::range_iterator<range_type>::type it = boost::begin(range);
- it != boost::end(range); ++it)
- {
- out << " " << bg::get<0>(*it) << bg::get<1>(*it);
- }
- BOOST_CHECK_EQUAL(out.str(), expected);
- }
-
- {
- // Check forward/backward behaviour
- std::ostringstream out;
- typename boost::range_iterator<range_type>::type it = boost::begin(range);
- it++;
- it--;
- out << " " << bg::get<0>(*it) << bg::get<1>(*it);
- typename boost::range_iterator<range_type>::type it2 = boost::end(range);
- it2--;
- out << " " << bg::get<0>(*it2) << bg::get<1>(*it2);
- BOOST_CHECK_EQUAL(out.str(), expected);
- }
-
- {
- // Check random access behaviour
- int const n = boost::size(range);
- BOOST_CHECK_EQUAL(n, 2);
- }
-
- // Check Boost.Range concept
- BOOST_CONCEPT_ASSERT( (boost::ForwardRangeConcept<range_type>) );
-
-}
-
-
-template <typename P>
-void test_all()
-{
- test_geometry<bg::model::segment<P> >("linestring(1 1,2 2)", " 11 22");
- test_geometry<bg::model::segment<P> >("linestring(4 4,3 3)", " 44 33");
-}
-
-
-int test_main(int, char* [])
-{
- test_all<bg::model::d2::point_xy<double> >();
- return 0;
-}

Deleted: trunk/libs/geometry/test/ranges/segment_range.vcproj
==============================================================================
--- trunk/libs/geometry/test/ranges/segment_range.vcproj 2011-05-07 18:13:16 EDT (Sat, 07 May 2011)
+++ (empty file)
@@ -1,178 +0,0 @@
-<?xml version="1.0" encoding="Windows-1252"?>
-<VisualStudioProject
- ProjectType="Visual C++"
- Version="8.00"
- Name="segment_range"
- ProjectGUID="{B49AC3E2-3497-465B-88C2-BCADA4B4ADAF}"
- RootNamespace="segment_range"
- Keyword="Win32Proj"
- >
- <Platforms>
- <Platform
- Name="Win32"
- />
- </Platforms>
- <ToolFiles>
- </ToolFiles>
- <Configurations>
- <Configuration
- Name="Debug|Win32"
- OutputDirectory="$(SolutionDir)$(ConfigurationName)"
- IntermediateDirectory="$(ConfigurationName)\segment_range"
- ConfigurationType="1"
- InheritedPropertySheets="..\boost.vsprops"
- CharacterSet="1"
- >
- <Tool
- Name="VCPreBuildEventTool"
- />
- <Tool
- Name="VCCustomBuildTool"
- />
- <Tool
- Name="VCXMLDataGeneratorTool"
- />
- <Tool
- Name="VCWebServiceProxyGeneratorTool"
- />
- <Tool
- Name="VCMIDLTool"
- />
- <Tool
- Name="VCCLCompilerTool"
- Optimization="0"
- AdditionalIncludeDirectories="../../../..;.."
- PreprocessorDefinitions="WIN32;_DEBUG;_CONSOLE"
- ExceptionHandling="2"
- RuntimeLibrary="1"
- UsePrecompiledHeader="0"
- WarningLevel="3"
- DebugInformationFormat="1"
- />
- <Tool
- Name="VCManagedResourceCompilerTool"
- />
- <Tool
- Name="VCResourceCompilerTool"
- />
- <Tool
- Name="VCPreLinkEventTool"
- />
- <Tool
- Name="VCLinkerTool"
- GenerateDebugInformation="true"
- SubSystem="1"
- TargetMachine="1"
- />
- <Tool
- Name="VCALinkTool"
- />
- <Tool
- Name="VCManifestTool"
- EmbedManifest="false"
- />
- <Tool
- Name="VCXDCMakeTool"
- />
- <Tool
- Name="VCBscMakeTool"
- />
- <Tool
- Name="VCFxCopTool"
- />
- <Tool
- Name="VCAppVerifierTool"
- />
- <Tool
- Name="VCWebDeploymentTool"
- />
- <Tool
- Name="VCPostBuildEventTool"
- />
- </Configuration>
- <Configuration
- Name="Release|Win32"
- OutputDirectory="$(SolutionDir)$(ConfigurationName)"
- IntermediateDirectory="$(ConfigurationName)\segment_range"
- ConfigurationType="1"
- InheritedPropertySheets="..\boost.vsprops"
- CharacterSet="1"
- WholeProgramOptimization="1"
- >
- <Tool
- Name="VCPreBuildEventTool"
- />
- <Tool
- Name="VCCustomBuildTool"
- />
- <Tool
- Name="VCXMLDataGeneratorTool"
- />
- <Tool
- Name="VCWebServiceProxyGeneratorTool"
- />
- <Tool
- Name="VCMIDLTool"
- />
- <Tool
- Name="VCCLCompilerTool"
- AdditionalIncludeDirectories="../../../..;.."
- PreprocessorDefinitions="WIN32;NDEBUG;_CONSOLE"
- ExceptionHandling="2"
- UsePrecompiledHeader="0"
- WarningLevel="3"
- />
- <Tool
- Name="VCManagedResourceCompilerTool"
- />
- <Tool
- Name="VCResourceCompilerTool"
- />
- <Tool
- Name="VCPreLinkEventTool"
- />
- <Tool
- Name="VCLinkerTool"
- SubSystem="1"
- OptimizeReferences="2"
- EnableCOMDATFolding="2"
- TargetMachine="1"
- />
- <Tool
- Name="VCALinkTool"
- />
- <Tool
- Name="VCManifestTool"
- EmbedManifest="false"
- />
- <Tool
- Name="VCXDCMakeTool"
- />
- <Tool
- Name="VCBscMakeTool"
- />
- <Tool
- Name="VCFxCopTool"
- />
- <Tool
- Name="VCAppVerifierTool"
- />
- <Tool
- Name="VCWebDeploymentTool"
- />
- <Tool
- Name="VCPostBuildEventTool"
- />
- </Configuration>
- </Configurations>
- <References>
- </References>
- <Files>
- <File
- RelativePath=".\segment_range.cpp"
- >
- </File>
- </Files>
- <Globals>
- </Globals>
-</VisualStudioProject>

Modified: trunk/libs/geometry/test/views/Jamfile.v2
==============================================================================
--- trunk/libs/geometry/test/views/Jamfile.v2 (original)
+++ trunk/libs/geometry/test/views/Jamfile.v2 2011-05-07 18:13:16 EDT (Sat, 07 May 2011)
@@ -10,6 +10,8 @@
 
 test-suite boost-geometry-views
     :
+ [ run segment_view.cpp ]
+ [ run box_view.cpp ]
     [ run reversible_view.cpp ]
     [ run closeable_view.cpp ]
     [ run reversible_closeable.cpp ]

Copied: trunk/libs/geometry/test/views/box_view.cpp (from r71629, /trunk/libs/geometry/test/ranges/box_range.cpp)
==============================================================================
--- /trunk/libs/geometry/test/ranges/box_range.cpp (original)
+++ trunk/libs/geometry/test/views/box_view.cpp 2011-05-07 18:13:16 EDT (Sat, 07 May 2011)
@@ -16,19 +16,19 @@
 
 #include <boost/geometry/geometries/geometries.hpp>
 #include <boost/geometry/geometries/point_xy.hpp>
-#include <boost/geometry/ranges/box_range.hpp>
+#include <boost/geometry/views/box_view.hpp>
 #include <boost/geometry/domains/gis/io/wkt/read_wkt.hpp>
 
 
 
-template <typename Box>
+template <typename Box, bool Reverse>
 void test_geometry(std::string const& wkt, std::string const& expected)
 {
 
     Box box;
     bg::read_wkt(wkt, box);
 
- typedef bg::box_range<Box> range_type;
+ typedef bg::box_view<Box, Reverse> range_type;
     range_type range(box);
 
     {
@@ -56,15 +56,16 @@
     }
 
     // Check Boost.Range concept
- BOOST_CONCEPT_ASSERT( (boost::ForwardRangeConcept<range_type>) );
+ BOOST_CONCEPT_ASSERT( (boost::RandomAccessRangeConcept<range_type>) );
 }
 
 
 template <typename P>
 void test_all()
 {
- test_geometry<bg::model::box<P> >("polygon((1 1,2 2))", " 11 12 22 21 11");
- test_geometry<bg::model::box<P> >("polygon((3 3,5 5))", " 33 35 55 53 33");
+ test_geometry<bg::model::box<P>, true> ("polygon((1 1,2 2))", " 11 12 22 21 11");
+ test_geometry<bg::model::box<P>, false>("polygon((1 1,2 2))", " 11 21 22 12 11");
+ test_geometry<bg::model::box<P>, true> ("polygon((3 3,5 5))", " 33 35 55 53 33");
 }
 
 

Copied: trunk/libs/geometry/test/views/box_view.vcproj (from r71623, /trunk/libs/geometry/test/ranges/box_range.vcproj)
==============================================================================
--- /trunk/libs/geometry/test/ranges/box_range.vcproj (original)
+++ trunk/libs/geometry/test/views/box_view.vcproj 2011-05-07 18:13:16 EDT (Sat, 07 May 2011)
@@ -2,9 +2,9 @@
 <VisualStudioProject
         ProjectType="Visual C++"
         Version="8.00"
- Name="box_range"
+ Name="box_view"
         ProjectGUID="{34A1F53A-DA46-41E6-9E26-740D22D662DC}"
- RootNamespace="box_range"
+ RootNamespace="box_view"
         Keyword="Win32Proj"
>
         <Platforms>
@@ -18,7 +18,7 @@
                 <Configuration
                         Name="Debug|Win32"
                         OutputDirectory="$(SolutionDir)$(ConfigurationName)"
- IntermediateDirectory="$(ConfigurationName)\box_range"
+ IntermediateDirectory="$(ConfigurationName)\box_view"
                         ConfigurationType="1"
                         InheritedPropertySheets="..\boost.vsprops"
                         CharacterSet="1"
@@ -93,7 +93,7 @@
                 <Configuration
                         Name="Release|Win32"
                         OutputDirectory="$(SolutionDir)$(ConfigurationName)"
- IntermediateDirectory="$(ConfigurationName)\box_range"
+ IntermediateDirectory="$(ConfigurationName)\box_view"
                         ConfigurationType="1"
                         InheritedPropertySheets="..\boost.vsprops"
                         CharacterSet="1"
@@ -169,7 +169,7 @@
         </References>
         <Files>
                 <File
- RelativePath=".\box_range.cpp"
+ RelativePath=".\box_view.cpp"
>
                 </File>
         </Files>

Copied: trunk/libs/geometry/test/views/segment_view.cpp (from r71629, /trunk/libs/geometry/test/ranges/segment_range.cpp)
==============================================================================
--- /trunk/libs/geometry/test/ranges/segment_range.cpp (original)
+++ trunk/libs/geometry/test/views/segment_view.cpp 2011-05-07 18:13:16 EDT (Sat, 07 May 2011)
@@ -15,7 +15,7 @@
 #include <geometry_test_common.hpp>
 
 #include <boost/geometry/geometries/geometries.hpp>
-#include <boost/geometry/ranges/segment_range.hpp>
+#include <boost/geometry/views/segment_view.hpp>
 #include <boost/geometry/domains/gis/io/wkt/read_wkt.hpp>
 
 
@@ -27,7 +27,7 @@
     Segment segment;
     bg::read_wkt(wkt, segment);
 
- typedef bg::segment_range<Segment> range_type;
+ typedef bg::segment_view<Segment> range_type;
     range_type range(segment);
 
     {
@@ -60,7 +60,7 @@
     }
 
     // Check Boost.Range concept
- BOOST_CONCEPT_ASSERT( (boost::ForwardRangeConcept<range_type>) );
+ BOOST_CONCEPT_ASSERT( (boost::RandomAccessRangeConcept<range_type>) );
 
 }
 
@@ -75,6 +75,11 @@
 
 int test_main(int, char* [])
 {
+ std::vector<int> a;
+ a.push_back(1);
+ boost::range_iterator<std::vector<int> const>::type it = a.end();
+ --it;
+ std::cout << *it << std::endl;
     test_all<bg::model::d2::point_xy<double> >();
     return 0;
 }

Copied: trunk/libs/geometry/test/views/segment_view.vcproj (from r71623, /trunk/libs/geometry/test/ranges/segment_range.vcproj)
==============================================================================
--- /trunk/libs/geometry/test/ranges/segment_range.vcproj (original)
+++ trunk/libs/geometry/test/views/segment_view.vcproj 2011-05-07 18:13:16 EDT (Sat, 07 May 2011)
@@ -2,9 +2,9 @@
 <VisualStudioProject
         ProjectType="Visual C++"
         Version="8.00"
- Name="segment_range"
+ Name="segment_view"
         ProjectGUID="{B49AC3E2-3497-465B-88C2-BCADA4B4ADAF}"
- RootNamespace="segment_range"
+ RootNamespace="segment_view"
         Keyword="Win32Proj"
>
         <Platforms>
@@ -18,7 +18,7 @@
                 <Configuration
                         Name="Debug|Win32"
                         OutputDirectory="$(SolutionDir)$(ConfigurationName)"
- IntermediateDirectory="$(ConfigurationName)\segment_range"
+ IntermediateDirectory="$(ConfigurationName)\segment_view"
                         ConfigurationType="1"
                         InheritedPropertySheets="..\boost.vsprops"
                         CharacterSet="1"
@@ -93,7 +93,7 @@
                 <Configuration
                         Name="Release|Win32"
                         OutputDirectory="$(SolutionDir)$(ConfigurationName)"
- IntermediateDirectory="$(ConfigurationName)\segment_range"
+ IntermediateDirectory="$(ConfigurationName)\segment_view"
                         ConfigurationType="1"
                         InheritedPropertySheets="..\boost.vsprops"
                         CharacterSet="1"
@@ -169,7 +169,7 @@
         </References>
         <Files>
                 <File
- RelativePath=".\segment_range.cpp"
+ RelativePath=".\segment_view.cpp"
>
                 </File>
         </Files>

Modified: trunk/libs/geometry/test/views/views.sln
==============================================================================
--- trunk/libs/geometry/test/views/views.sln (original)
+++ trunk/libs/geometry/test/views/views.sln 2011-05-07 18:13:16 EDT (Sat, 07 May 2011)
@@ -6,6 +6,10 @@
 EndProject
 Project("{8BC9CEB8-8B4A-11D0-8D11-00A0C91BC942}") = "reversible_view", "reversible_view.vcproj", "{BFB08FEE-76D6-4F3D-9184-BE03CC3F7968}"
 EndProject
+Project("{8BC9CEB8-8B4A-11D0-8D11-00A0C91BC942}") = "box_view", "box_view.vcproj", "{34A1F53A-DA46-41E6-9E26-740D22D662DC}"
+EndProject
+Project("{8BC9CEB8-8B4A-11D0-8D11-00A0C91BC942}") = "segment_view", "segment_view.vcproj", "{B49AC3E2-3497-465B-88C2-BCADA4B4ADAF}"
+EndProject
 Global
         GlobalSection(SolutionConfigurationPlatforms) = preSolution
                 Debug|Win32 = Debug|Win32
@@ -24,6 +28,14 @@
                 {BFB08FEE-76D6-4F3D-9184-BE03CC3F7968}.Debug|Win32.Build.0 = Debug|Win32
                 {BFB08FEE-76D6-4F3D-9184-BE03CC3F7968}.Release|Win32.ActiveCfg = Release|Win32
                 {BFB08FEE-76D6-4F3D-9184-BE03CC3F7968}.Release|Win32.Build.0 = Release|Win32
+ {34A1F53A-DA46-41E6-9E26-740D22D662DC}.Debug|Win32.ActiveCfg = Debug|Win32
+ {34A1F53A-DA46-41E6-9E26-740D22D662DC}.Debug|Win32.Build.0 = Debug|Win32
+ {34A1F53A-DA46-41E6-9E26-740D22D662DC}.Release|Win32.ActiveCfg = Release|Win32
+ {34A1F53A-DA46-41E6-9E26-740D22D662DC}.Release|Win32.Build.0 = Release|Win32
+ {B49AC3E2-3497-465B-88C2-BCADA4B4ADAF}.Debug|Win32.ActiveCfg = Debug|Win32
+ {B49AC3E2-3497-465B-88C2-BCADA4B4ADAF}.Debug|Win32.Build.0 = Debug|Win32
+ {B49AC3E2-3497-465B-88C2-BCADA4B4ADAF}.Release|Win32.ActiveCfg = Release|Win32
+ {B49AC3E2-3497-465B-88C2-BCADA4B4ADAF}.Release|Win32.Build.0 = Release|Win32
         EndGlobalSection
         GlobalSection(SolutionProperties) = preSolution
                 HideSolutionNode = FALSE


Boost-Commit list run by bdawes at acm.org, david.abrahams at rcn.com, gregod at cs.rpi.edu, cpdaniel at pacbell.net, john at johnmaddock.co.uk
--- /trunk/libs/geometry/doc/src/examples/ranges/box_range.cpp (original)
+++ trunk/libs/geometry/doc/src/examples/views/box_view.cpp 2011-05-07 18:13:16 EDT (Sat, 07 May 2011)
@@ -7,7 +7,7 @@
 // Version 1.0. (See accompanying file LICENSE_1_0.txt or copy at
 // http://www.boost.org/LICENSE_1_0.txt)
 
-//[box_range
+//[box_view
 //` Shows usage of the Boost.Range compatible view on a box
 
 #include <iostream>
@@ -23,23 +23,23 @@
> box_type;
         
     // Define the Boost.Range compatible type:
- typedef boost::geometry::box_range<box_type> box_range;
+ typedef boost::geometry::box_view<box_type> box_view;
         
     box_type box;
     boost::geometry::assign_values(box, 0, 0, 4, 4);
     
- box_range range(box);
+ box_view view(box);
     
     // Iterating in clockwise direction over the points of this box
- for (boost::range_iterator<box_range const>::type it = boost::begin(range);
- it != boost::end(range); ++it)
+ for (boost::range_iterator<box_view const>::type it = boost::begin(view);
+ it != boost::end(view); ++it)
     {
         std::cout << " " << boost::geometry::dsv(*it);
     }
     std::cout << std::endl;
     
- // Note that a box_range is tagged as a ring, so supports area etc.
- std::cout << "Area: " << boost::geometry::area(range) << std::endl;
+ // Note that a box_view is tagged as a ring, so supports area etc.
+ std::cout << "Area: " << boost::geometry::area(view) << std::endl;
     
     return 0;
 }
@@ -47,7 +47,7 @@
 //]
 
 
-//[box_range_output
+//[box_view_output
 /*`
 Output:
 [pre

Added: trunk/libs/geometry/doc/src/examples/views/segment_view.cpp
==============================================================================